@@ -34,7 +34,6 @@ struct PluginPageListItem {
     KTextEditor::Plugin *plugin;
     int idInPlugin;
     KTextEditor::ConfigPage *pluginPage;
-    QWidget *pageParent;
     KPageWidgetItem *pageWidgetItem;
 };
 
@@ -89,7 +88,7 @@ private:
 
     Ui::SessionConfigWidget sessionConfigUi;
 
-    QHash<KPageWidgetItem *, PluginPageListItem *> m_pluginPages;
+    QHash<KPageWidgetItem *, PluginPageListItem> m_pluginPages;
     QList<KTextEditor::ConfigPage *> m_editorPages;
 
 #ifdef WITH_KUSERFEEDBACK
